Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(786)

Unified Diff: components/variations/variations_seed_processor.h

Issue 2924983003: [Variations] Refactor all state used for study filtering into a container struct. (Closed)
Patch Set: A bit more cleanup Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/variations/variations_seed_processor.h
diff --git a/components/variations/variations_seed_processor.h b/components/variations/variations_seed_processor.h
index bcb938ad064d7005eb383c6a38b42273ad865734..140dc2714a96e05717d09a001a419cd3e1ee41a2 100644
--- a/components/variations/variations_seed_processor.h
+++ b/components/variations/variations_seed_processor.h
@@ -28,6 +28,7 @@ class FeatureList;
namespace variations {
class ProcessedStudy;
+struct ClientFilterableState;
// Helper class to instantiate field trials from a variations seed.
class VariationsSeedProcessor {
@@ -38,20 +39,13 @@ class VariationsSeedProcessor {
VariationsSeedProcessor();
virtual ~VariationsSeedProcessor();
// Creates field trials from the specified variations |seed|, based on the
// specified configuration, as specified in the parameters. Any study that
// should use low entropy will use |low_entropy_provider| for group
// selection. These studies are defined by ShouldStudyUseLowEntropy;
void CreateTrialsFromSeed(
const VariationsSeed& seed,
- const std::string& locale,
- const base::Time& reference_date,
- const base::Version& version,
- Study_Channel channel,
- Study_FormFactor form_factor,
- const std::string& hardware_class,
- const std::string& session_consistency_country,
- const std::string& permanent_consistency_country,
+ const ClientFilterableState& client_state,
const UIStringOverrideCallback& override_callback,
const base::FieldTrial::EntropyProvider* low_entropy_provider,
base::FeatureList* feature_list);
@@ -38,20 +39,13 @@ class VariationsSeedProcessor {
VariationsSeedProcessor();
virtual ~VariationsSeedProcessor();
- // Creates field trials from the specified variations |seed|, based on the
- // specified configuration, as specified in the parameters. Any study that
- // should use low entropy will use |low_entropy_provider| for group
- // selection. These studies are defined by ShouldStudyUseLowEntropy;
+ // Creates field trials from the specified variations |seed|, filtered
+ // according to the client's |client_state|. Any study that should use low
+ // entropy will use |low_entropy_provider| for group selection. These studies
+ // are defined by ShouldStudyUseLowEntropy;
void CreateTrialsFromSeed(
const VariationsSeed& seed,
« no previous file with comments | « components/variations/study_filtering_unittest.cc ('k') | components/variations/variations_seed_processor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698